ClassInfoBuilder

Struct ClassInfoBuilder 

pub struct ClassInfoBuilder<'a> { /* private fields */ }
A builder for ClassInfo

See general documentation about this pattern.

We use a builder here to allow future additional options to not break the API.

Implementations

Source

impl<'a> ClassInfoBuilder<'a>

pub const fn new( name: &'a str, cid: ClassID, edit_controller_cid: ClassID, ui_initial_size: UiSize, ) -> Self

Create a new ClassInfoBuilder

pub const fn resizable(self, options: ResizingOptions) -> Self

Make the component resizeable with optional min and max sizes.

If you don’t provide min or max sizes, there will be no size constraints.

pub const fn build(self) -> ClassInfo<'a>

Build the ClassInfo

Panics

If the initial size is not within the min and max size bounds or the min size is greater than the max size in either dimension.