pub struct ClassInfoBuilder<'a> { /* private fields */ }Expand description
A builder for ClassInfo
See general documentation about this pattern.
We use a builder here to allow future additional options to not break the API.
Implementations
Sourceimpl<'a> ClassInfoBuilder<'a>
impl<'a> ClassInfoBuilder<'a>
Sourcepub const fn new(
name: &'a str,
cid: ClassID,
edit_controller_cid: ClassID,
ui_initial_size: UiSize,
) -> Self
pub const fn new( name: &'a str, cid: ClassID, edit_controller_cid: ClassID, ui_initial_size: UiSize, ) -> Self
Create a new ClassInfoBuilder
Sourcepub const fn resizable(self, options: ResizingOptions) -> Self
pub const fn resizable(self, options: ResizingOptions) -> Self
Make the component resizeable with optional min and max sizes.
If you don’t provide min or max sizes, there will be no size constraints.